( cd usr/bin ; rm -rf tixwish )
( cd usr/bin ; ln -sf tixwish8.1.8.4 tixwish )
( cd usr/lib ; rm -rf libtix.so )
( cd usr/lib ; ln -sf libtix8.1.8.4.so libtix.so )
( cd usr/lib ; rm -rf libtixsam.so )
( cd usr/lib ; ln -sf libtixsam8.1.8.4.so libtixsam.so )
